/**
 * Most rooms have a grid index corresponding to their position on the level layout grid. Valid grid
 * indexes range from 0 through 168 (because the grid is 13x13). However, some rooms are not part of
 * the level layout grid. For off-grid rooms, they are assigned special negative integers that
 * correspond to what kind of room they are. This enum contains all of the special negative values
 * that exist.
 */
export var GridRoom;
(function (GridRoom) {
    /** The Devil or Angel room for the floor. */
    GridRoom[GridRoom["DEVIL"] = -1] = "DEVIL";
    /** The I AM ERROR room for the floor. */
    GridRoom[GridRoom["ERROR"] = -2] = "ERROR";
    /** Used by the "goto" console command. */
    GridRoom[GridRoom["DEBUG"] = -3] = "DEBUG";
    /** The crawl space for the floor. */
    GridRoom[GridRoom["DUNGEON"] = -4] = "DUNGEON";
    GridRoom[GridRoom["BOSS_RUSH"] = -5] = "BOSS_RUSH";
    GridRoom[GridRoom["BLACK_MARKET"] = -6] = "BLACK_MARKET";
    /** Mega Satan's boss room. */
    GridRoom[GridRoom["MEGA_SATAN"] = -7] = "MEGA_SATAN";
    /** The room after defeating It Lives that leads to Blue Womb. */
    GridRoom[GridRoom["BLUE_WOMB"] = -8] = "BLUE_WOMB";
    /** The room after defeating Hush that leads to The Void. */
    GridRoom[GridRoom["VOID"] = -9] = "VOID";
    /**
     * The room that is connected to the Boss Room that leads to the next Repentance floor.
     *
     * Additionally, this grid index is also used for the room behind the strange door on Depths 2
     * that is connected to the starting room.
     */
    GridRoom[GridRoom["SECRET_EXIT"] = -10] = "SECRET_EXIT";
    /** The secret crawl space under Great Gideon that is only accessible with a Chaos Card. */
    GridRoom[GridRoom["GIDEON_DUNGEON"] = -11] = "GIDEON_DUNGEON";
    /** The Genesis room where you get to take new collectibles. (It looks like a clean bedroom.) */
    GridRoom[GridRoom["GENESIS"] = -12] = "GENESIS";
    /** The shop that appears if you have Member Card. */
    GridRoom[GridRoom["SECRET_SHOP"] = -13] = "SECRET_SHOP";
    /** The boss room for the 2nd phase of Rotgut. */
    GridRoom[GridRoom["ROTGUT_DUNGEON_1"] = -14] = "ROTGUT_DUNGEON_1";
    /** The boss room for the 3rd phase of Rotgut. */
    GridRoom[GridRoom["ROTGUT_DUNGEON_2"] = -15] = "ROTGUT_DUNGEON_2";
    /** The room before a Treasure Room that appears if you have Blue Key. */
    GridRoom[GridRoom["BLUE_ROOM"] = -16] = "BLUE_ROOM";
    /** The room that you are teleported to when you use a Reverse Emperor card. */
    GridRoom[GridRoom["EXTRA_BOSS"] = -17] = "EXTRA_BOSS";
    /** The shop that you go to when you climb the ladder from The Stairway. */
    GridRoom[GridRoom["ANGEL_SHOP"] = -18] = "ANGEL_SHOP";
})(GridRoom || (GridRoom = {}));
